@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '1.98';
+$CPAN::Perl::Releases::VERSION = '2.02';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -155,7 +155,8 @@ our $data =
 "5.18.3" => { id => 'RJBS' },
 "5.18.4" => { id => 'RJBS' },
 "5.21.5" => { id => 'ABIGAIL' },
-"5.21.6" => { id => 'BINGOS' },
+"5.21.6" => { id => 'BINGOS', xz => 1 },
+"5.21.7" => { id => 'CORION', xz => 1 },
 };
 
 sub perl_tarballs {
@@ -174,6 +175,7 @@ sub perl_tarballs {
   my $foo = { };
   $foo->{'tar.gz'} = "$path/$perl.tar.gz" unless $onlybz2;
   $foo->{'tar.bz2'} = "$path/$perl.tar.bz2" unless $onlygz;
+  $foo->{'tar.xz'} = "$path/$perl.tar.xz" if $data->{ $vers }->{xz};
   $cache->{ $vers } = $foo;
   return { %$foo };
 }
@@ -212,7 +214,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.98
+version 2.02
 
 =head1 SYNOPSIS
 
@@ -254,6 +256,8 @@ on CPAN where the indicated tarball will be located.
 
 Not all C<perl> releases had C<tar.bz2>, but only a C<tar.gz>.
 
+Perl tarballs may also be compressed using C<xz> and therefore have a C<tar.xz> entry.
+
 =item C<perl_versions>
 
 Returns the list of all the perl versions supported by the module in ascending order. C<TRIAL> and C<RC> will be lower
